/** @module @lexical/markdown */
/**
 * Copyright (c) Meta Platforms, Inc. and affiliates.
 *
 * This source code is licensed under the MIT license found in the
 * LICENSE file in the root directory of this source tree.
 *
 */

import {createMarkdownImport} from '@/components/MarkDown/MarkdownImport';
import {registerMarkdownShortcuts} from '@lexical/markdown';
import {
    BOLD_ITALIC_STAR,
    BOLD_ITALIC_UNDERSCORE,
    BOLD_STAR,
    BOLD_UNDERSCORE,
    CHECK_LIST,
    CODE,
    HEADING,
    HIGHLIGHT,
    INLINE_CODE,
    ITALIC_STAR,
    ITALIC_UNDERSCORE,
    ORDERED_LIST,
    QUOTE,
    STRIKETHROUGH,
    UNORDERED_LIST,
} from '@lexical/markdown';
import {LINK,IMAGE} from "@/components/MarkDown/MarkdownTransformers";
import {createMarkdownExport} from "@/components/MarkDown/MarkDownExport";

const ELEMENT_TRANSFORMERS= [
    HEADING,
    QUOTE,
    CODE,
    UNORDERED_LIST,
    ORDERED_LIST,
];

// Order of text format transformers matters:
//
// - code should go first as it prevents any transformations inside
// - then longer tags match (e.g. ** or __ should go before * or _)
const TEXT_FORMAT_TRANSFORMERS = [
    INLINE_CODE,
    BOLD_ITALIC_STAR,
    BOLD_ITALIC_UNDERSCORE,
    BOLD_STAR,
    BOLD_UNDERSCORE,
    HIGHLIGHT,
    ITALIC_STAR,
    ITALIC_UNDERSCORE,
    STRIKETHROUGH,
];

const TEXT_MATCH_TRANSFORMERS= [LINK,IMAGE];

const TRANSFORMERS = [
    ...ELEMENT_TRANSFORMERS,
    ...TEXT_FORMAT_TRANSFORMERS,
    ...TEXT_MATCH_TRANSFORMERS,
];

function $convertFromMarkdownString(
    markdown,
    transformers = TRANSFORMERS,
    node,
) {
    const importMarkdown = createMarkdownImport(transformers);
    return importMarkdown(markdown, node);
}

function $convertToMarkdownString(
    transformers,
    node,
) {
    const exportMarkdown = createMarkdownExport(transformers);
    return exportMarkdown(node);
}

export {
    $convertFromMarkdownString,
    $convertToMarkdownString,
    BOLD_ITALIC_STAR,
    BOLD_ITALIC_UNDERSCORE,
    BOLD_STAR,
    BOLD_UNDERSCORE,
    CHECK_LIST,
    CODE,
    ELEMENT_TRANSFORMERS,
    HEADING,
    HIGHLIGHT,
    INLINE_CODE,
    ITALIC_STAR,
    ITALIC_UNDERSCORE,
    LINK,
    ORDERED_LIST,
    QUOTE,
    registerMarkdownShortcuts,
    STRIKETHROUGH,
    TEXT_FORMAT_TRANSFORMERS,
    TEXT_MATCH_TRANSFORMERS,
    TRANSFORMERS,
    UNORDERED_LIST,
};
