const fs = window.require("fs").promises
const synchronizedFs = window.require("fs")
const {ipcRenderer,dialog} = window.require('electron')
const pathOp = window.require("path")
export async function readDir(filePath){
    const files = await fs.readdir(filePath);
    const fileStateList = []
    const fileChildList = []
    fileStateList.push({
        "fileName": filePath,
        "filePath": filePath,
        "dirFlag": true,
        "children": fileChildList
    })
    for (let i = 0; i < files.length; i++) {
        const state = await fs.stat(filePath + pathOp.sep + files[i]);
        if (state.isDirectory()
            || files[i].endsWith(".md")
            || files[i].endsWith(".html")
            || files[i].endsWith(".lexical")) {
            fileChildList.push({
                'fileName': files[i],
                "filePath": filePath + pathOp.sep + files[i],
                'dirFlag': state.isDirectory(),
                "children":[]
            })
        }
    }
    return fileStateList
}
export async function importFile(pathName) {
    return await fs.readFile(pathName)
}

export async function overWriteFile(filePath,jsonText) {
    await fs.writeFile(filePath,jsonText,{"encoding":"utf-8"})
}

export async function newDir(filePath) {
    await fs.mkdir(filePath)
}
export async function newFile(filePath) {
    await fs.writeFile(filePath,"",{"encoding":"utf-8"})
}
export async function deleteFileAndDir(filePath) {
    await fs.rm(filePath)
}

export async function updateFileName(oldFileName,newFileName){
    await fs.rename(oldFileName,newFileName)
}

export async function saveFileWithName(){
    return ipcRenderer.invoke("saveFileWithName" )
}

export async function openInDir(filePath){
    // return dialog.showOpenDialog({defaultPath:filePath,properties: ['openDirectory']} )
    console.log("pathOp.dirname(filePath.filePath)"+pathOp.dirname(filePath.filePath))
    return ipcRenderer.invoke("showOpenDialog",pathOp.dirname(filePath.filePath))
}

export function convertAndSaveImage(dataURL, outputPath) {
    try {
        let dir = pathOp.dirname(outputPath);
        let finalDir = dir+pathOp.sep+"img";
        if (!synchronizedFs.existsSync(finalDir)){
            synchronizedFs.mkdirSync(finalDir);
        }
        const base64Data = dataURL.replace(/^data:image\/png;base64,/, '');
        const buffer = Buffer.from(base64Data, 'base64');
        let fileName = new Date().getTime()+".png";
        fs.writeFile(finalDir+pathOp.sep+fileName, buffer)
        // 相对路径
        // return "img"+pathOp.sep+fileName;
        // 绝对路径
        return finalDir+pathOp.sep+fileName;
    } catch (error) {
        console.error('Error converting and saving image:', error);
    }
}

function isAbsolutePath(filePath) {
    return pathOp.isAbsolute(filePath);
}